==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestStatusFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateRequestStatusFluent<A extends CertificateRequestStatusFluent<A>> extends Fluent<A>{
  public String getCa();
  public A withCa(String ca);
  public Boolean hasCa();
  public String getCertificate();
  public A withCertificate(String certificate);
  public Boolean hasCertificate();
  public A addToConditions(Integer index,CertificateRequestCondition item);
  public A setToConditions(Integer index,CertificateRequestCondition item);
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... items);
  public A addAllToConditions(Collection<CertificateRequestCondition> items);
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... items);
  public A removeAllFromConditions(Collection<CertificateRequestCondition> items);
  public A removeMatchingFromConditions(Predicate<CertificateRequestConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateRequestCondition> getConditions();
  public List<CertificateRequestCondition> buildConditions();
  public CertificateRequestCondition buildCondition(Integer index);
  public CertificateRequestCondition buildFirstCondition();
  public CertificateRequestCondition buildLastCondition();
  public CertificateRequestCondition buildMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public A withConditions(List<CertificateRequestCondition> conditions);
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public CertificateRequestStatusFluent.ConditionsNested<A> addNewCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> addNewConditionLike(CertificateRequestCondition item);
  public CertificateRequestStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,CertificateRequestCondition item);
  public CertificateRequestStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public CertificateRequestStatusFluent.ConditionsNested<A> editFirstCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> editLastCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public String getFailureTime();
  public A withFailureTime(String failureTime);
  public Boolean hasFailureTime();
  public interface ConditionsNested<N> extends Nested<N>,CertificateRequestConditionFluent<CertificateRequestStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestStatusFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateRequestStatusFluent<A extends CertificateRequestStatusFluent<A>> extends Fluent<A>{
  public String getCa();
  public A withCa(String ca);
  public Boolean hasCa();
  public String getCertificate();
  public A withCertificate(String certificate);
  public Boolean hasCertificate();
  public A addToConditions(int index,CertificateRequestCondition item);
  public A setToConditions(int index,CertificateRequestCondition item);
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... items);
  public A addAllToConditions(Collection<CertificateRequestCondition> items);
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... items);
  public A removeAllFromConditions(Collection<CertificateRequestCondition> items);
  public A removeMatchingFromConditions(Predicate<CertificateRequestConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateRequestCondition> getConditions();
  public List<CertificateRequestCondition> buildConditions();
  public CertificateRequestCondition buildCondition(int index);
  public CertificateRequestCondition buildFirstCondition();
  public CertificateRequestCondition buildLastCondition();
  public CertificateRequestCondition buildMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public A withConditions(List<CertificateRequestCondition> conditions);
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public CertificateRequestStatusFluent.ConditionsNested<A> addNewCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> addNewConditionLike(CertificateRequestCondition item);
  public CertificateRequestStatusFluent.ConditionsNested<A> setNewConditionLike(int index,CertificateRequestCondition item);
  public CertificateRequestStatusFluent.ConditionsNested<A> editCondition(int index);
  public CertificateRequestStatusFluent.ConditionsNested<A> editFirstCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> editLastCondition();
  public CertificateRequestStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CertificateRequestConditionBuilder> predicate);
  public String getFailureTime();
  public A withFailureTime(String failureTime);
  public Boolean hasFailureTime();
  public interface ConditionsNested<N> extends Nested<N>,CertificateRequestConditionFluent<CertificateRequestStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
